@@ -1,7 +1,7 @@
 /****************************************************************************
 **
-** Copyright (C) 2014 Digia Plc and/or its subsidiary(-ies).
-** Contact: http://www.qt-project.org/legal
+** Copyright (C) 2015 The Qt Company Ltd.
+** Contact: http://www.qt.io/licensing/
 **
 ** This file is part of the QtBluetooth module of the Qt Toolkit.
 **
@@ -10,9 +10,9 @@
 ** Licensees holding valid commercial Qt licenses may use this file in
 ** accordance with the commercial license agreement provided with the
 ** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and Digia. For licensing terms and
-** conditions see http://qt.digia.com/licensing. For further information
-** use the contact form at http://qt.digia.com/contact-us.
+** a written agreement between you and The Qt Company. For licensing terms
+** and conditions see http://www.qt.io/terms-conditions. For further
+** information use the contact form at http://www.qt.io/contact-us.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
@@ -23,8 +23,8 @@
 ** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
 ** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
-** In addition, as a special exception, Digia gives you certain additional
-** rights. These rights are described in the Digia Qt LGPL Exception
+** As a special exception, The Qt Company gives you certain additional
+** rights. These rights are described in The Qt Company LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
 ** $QT_END_LICENSE$
@@ -40,11 +40,14 @@ import android.util.Log;
 import java.io.IOException;
 import java.util.UUID;
 
+@SuppressWarnings("WeakerAccess")
 public class QtBluetoothSocketServer extends Thread
 {
 
     /* Pointer to the Qt object that "owns" the Java object */
+    @SuppressWarnings({"WeakerAccess", "CanBeFinal"})
     long qtObject = 0;
+    @SuppressWarnings({"WeakerAccess", "CanBeFinal"})
     public boolean logEnabled = false;
 
     private static final String TAG = "QtBluetooth";
@@ -54,9 +57,9 @@ public class QtBluetoothSocketServer extends Thread
     private BluetoothServerSocket m_serverSocket = null;
 
     //error codes
-    public static final int QT_NO_BLUETOOTH_SUPPORTED = 0;
-    public static final int QT_LISTEN_FAILED = 1;
-    public static final int QT_ACCEPT_FAILED = 2;
+    private static final int QT_NO_BLUETOOTH_SUPPORTED = 0;
+    private static final int QT_LISTEN_FAILED = 1;
+    private static final int QT_ACCEPT_FAILED = 2;
 
     public QtBluetoothSocketServer()
     {
@@ -97,7 +100,7 @@ public class QtBluetoothSocketServer extends Thread
             return;
         }
 
-        BluetoothSocket s = null;
+        BluetoothSocket s;
         if (m_serverSocket != null) {
             try {
                 while (!isInterrupted()) {
