@@ -1,40 +1,32 @@
 /****************************************************************************
 **
-** Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
-** Contact: http://www.qt-project.org/legal
+** Copyright (C) 2015 The Qt Company Ltd.
+** Contact: http://www.qt.io/licensing/
 **
 ** This file is part of the QtBluetooth module of the Qt Toolkit.
 **
-** $QT_BEGIN_LICENSE:LGPL$
+** $QT_BEGIN_LICENSE:LGPL21$
 ** Commercial License Usage
 ** Licensees holding valid commercial Qt licenses may use this file in
 ** accordance with the commercial license agreement provided with the
 ** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and Digia.  For licensing terms and
-** conditions see http://qt.digia.com/licensing.  For further information
-** use the contact form at http://qt.digia.com/contact-us.
+** a written agreement between you and The Qt Company. For licensing terms
+** and conditions see http://www.qt.io/terms-conditions. For further
+** information use the contact form at http://www.qt.io/contact-us.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 2.1 as published by the Free Software
-** Foundation and appearing in the file LICENSE.LGPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU Lesser General Public License version 2.1 requirements
-** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
+** General Public License version 2.1 or version 3 as published by the Free
+** Software Foundation and appearing in the file LICENSE.LGPLv21 and
+** LICENSE.LGPLv3 included in the packaging of this file. Please review the
+** following information to ensure the GNU Lesser General Public License
+** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
+** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
-** In addition, as a special exception, Digia gives you certain additional
-** rights.  These rights are described in the Digia Qt LGPL Exception
+** As a special exception, The Qt Company gives you certain additional
+** rights. These rights are described in The Qt Company LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
-**
-**
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -51,6 +43,8 @@ QT_BEGIN_NAMESPACE
     \brief The QBluetoothDeviceDiscoveryAgent class discovers the Bluetooth
     devices nearby.
 
+    \since 5.2
+
     To discover the nearby Bluetooth devices:
     \list
     \li create an instance of QBluetoothDeviceDiscoveryAgent,
@@ -62,6 +56,14 @@ QT_BEGIN_NAMESPACE
 
     To retrieve results asynchronously, connect to the deviceDiscovered() signal. To get a list of
     all discovered devices, call discoveredDevices() after the finished() signal.
+
+    This class can be used to discover Classic and Low Energy Bluetooth devices.
+    The individual device type can be determined via the
+    \l QBluetoothDeviceInfo::coreConfigurations() attribute.
+    In most cases the list returned by \l discoveredDevices() contains both types
+    of devices. However not every platform can detect both types of devices.
+    On platforms with this limitation (for example iOS only suports Low Energy discovery),
+    the discovery process will limit the search to the type which is supported.
 */
 
 /*!
@@ -74,6 +76,10 @@ QT_BEGIN_NAMESPACE
     \value InputOutputError    Writing or reading from the device resulted in an error.
     \value InvalidBluetoothAdapterError The passed local adapter address does not match the physical
                                         adapter address of any local Bluetooth device.
+    \value UnsupportedPlatformError Device discovery is not possible or implemented on the current
+                                    platform. The error is set in response to a call to \l start().
+                                    An example for such cases are iOS versions below 5.0 which do not support
+                                    Bluetooth device search at all. This value was introduced by Qt 5.5.
     \value UnknownError     An unknown error has occurred.
 */
 
@@ -99,6 +105,16 @@ QT_BEGIN_NAMESPACE
     \fn void QBluetoothDeviceDiscoveryAgent::deviceDiscovered(const QBluetoothDeviceInfo &info)
 
     This signal is emitted when the Bluetooth device described by \a info is discovered.
+
+    The signal is emitted as soon as the most important device information
+    has been collected. However, as long as the \l finished() signal has not
+    been emitted the information collection continues even for already discovered
+    devices. This is particularly true for signal strength information (RSSI). If
+    signal strength information is required it is advisable to retrieve the device
+    information via \l discoveredDevices() once the discovery has finished. This
+    will yield the most recent RSSI information.
+
+    \sa QBluetoothDeviceInfo::rssi()
 */
 
 /*!
@@ -132,10 +148,10 @@ QT_BEGIN_NAMESPACE
 /*!
     Constructs a new Bluetooth device discovery agent with parent \a parent.
 */
-QBluetoothDeviceDiscoveryAgent::QBluetoothDeviceDiscoveryAgent(QObject *parent)
-    : QObject(parent), d_ptr(new QBluetoothDeviceDiscoveryAgentPrivate(QBluetoothAddress()))
+QBluetoothDeviceDiscoveryAgent::QBluetoothDeviceDiscoveryAgent(QObject *parent) :
+    QObject(parent),
+    d_ptr(new QBluetoothDeviceDiscoveryAgentPrivate(QBluetoothAddress(), this))
 {
-    d_ptr->q_ptr = this;
 }
 
 /*!
@@ -150,10 +166,11 @@ QBluetoothDeviceDiscoveryAgent::QBluetoothDeviceDiscoveryAgent(QObject *parent)
 
     \sa error()
 */
-QBluetoothDeviceDiscoveryAgent::QBluetoothDeviceDiscoveryAgent(const QBluetoothAddress &deviceAdapter, QObject *parent)
-    : QObject(parent), d_ptr(new QBluetoothDeviceDiscoveryAgentPrivate(deviceAdapter))
+QBluetoothDeviceDiscoveryAgent::QBluetoothDeviceDiscoveryAgent(
+    const QBluetoothAddress &deviceAdapter, QObject *parent) :
+    QObject(parent),
+    d_ptr(new QBluetoothDeviceDiscoveryAgentPrivate(deviceAdapter, this))
 {
-    d_ptr->q_ptr = this;
     if (!deviceAdapter.isNull()) {
         const QList<QBluetoothHostInfo> localDevices = QBluetoothLocalDevice::allDevices();
         foreach (const QBluetoothHostInfo &hostInfo, localDevices) {
@@ -238,7 +255,6 @@ bool QBluetoothDeviceDiscoveryAgent::isActive() const
     return d->isActive();
 }
 
-
 /*!
     Returns the last error.
 */
@@ -261,4 +277,3 @@ QString QBluetoothDeviceDiscoveryAgent::errorString() const
 #include "moc_qbluetoothdevicediscoveryagent.cpp"
 
 QT_END_NAMESPACE
-
