@@ -1,40 +1,32 @@
 /****************************************************************************
 **
-** Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
-** Contact: http://www.qt-project.org/legal
+** Copyright (C) 2015 The Qt Company Ltd.
+** Contact: http://www.qt.io/licensing/
 **
 ** This file is part of the QtBluetooth module of the Qt Toolkit.
 **
-** $QT_BEGIN_LICENSE:LGPL$
+** $QT_BEGIN_LICENSE:LGPL21$
 ** Commercial License Usage
 ** Licensees holding valid commercial Qt licenses may use this file in
 ** accordance with the commercial license agreement provided with the
 ** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and Digia.  For licensing terms and
-** conditions see http://qt.digia.com/licensing.  For further information
-** use the contact form at http://qt.digia.com/contact-us.
+** a written agreement between you and The Qt Company. For licensing terms
+** and conditions see http://www.qt.io/terms-conditions. For further
+** information use the contact form at http://www.qt.io/contact-us.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 2.1 as published by the Free Software
-** Foundation and appearing in the file LICENSE.LGPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU Lesser General Public License version 2.1 requirements
-** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
+** General Public License version 2.1 or version 3 as published by the Free
+** Software Foundation and appearing in the file LICENSE.LGPLv21 and
+** LICENSE.LGPLv3 included in the packaging of this file. Please review the
+** following information to ensure the GNU Lesser General Public License
+** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
+** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
-** In addition, as a special exception, Digia gives you certain additional
-** rights.  These rights are described in the Digia Qt LGPL Exception
+** As a special exception, The Qt Company gives you certain additional
+** rights. These rights are described in The Qt Company LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
-**
-**
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -52,6 +44,8 @@ QT_BEGIN_NAMESPACE
     \brief The Sequence class stores attributes of a Bluetooth Data Element
     Sequence.
 
+    \since 5.2
+
 */
 
 /*!
@@ -72,6 +66,7 @@ QT_BEGIN_NAMESPACE
     \brief The Alternative class stores attributes of a Bluetooth Data Element
     Alternative.
 
+    \since 5.2
 */
 
 /*!
@@ -92,6 +87,8 @@ QT_BEGIN_NAMESPACE
     \brief The QBluetoothServiceInfo class enables access to the attributes of a
     Bluetooth service.
 
+    \since 5.2
+
     QBluetoothServiceInfo provides information about a service offered by a Bluetooth device.
     In addition it can be used to register new services on the local device. Note that such
     a registration only affects the Bluetooth SDP entries. Any server listening
@@ -137,7 +134,8 @@ QT_BEGIN_NAMESPACE
     This enum describes the socket protocol used by the service.
 
     \value UnknownProtocol  The service uses an unknown socket protocol.
-    \value L2capProtocol    The service uses the L2CAP socket protocol.
+    \value L2capProtocol    The service uses the L2CAP socket protocol. This protocol is not supported
+                            for direct socket connections on Android and BlackBerry.
     \value RfcommProtocol   The service uses the RFCOMM socket protocol.
 */
 
@@ -315,7 +313,8 @@ bool QBluetoothServiceInfo::unregisterService()
     This is a convenience function. It is equivalent to calling
     setAttribute(QBluetoothServiceInfo::ServiceId, uuid).
 
-    Sets the service UUID to \a uuid.
+    Sets the custom service UUID to \a uuid. This function should not be used
+    to set a standardized service UUID.
 
     \sa serviceUuid(), setAttribute()
 */
@@ -326,23 +325,13 @@ bool QBluetoothServiceInfo::unregisterService()
     This is a convenience function. It is equivalent to calling
     attribute(QBluetoothServiceInfo::ServiceId).value<QBluetoothUuid>().
 
-    Returns the UUID of the service.
+    Returns the custom UUID of the service. This UUID may be null.
+    UUIDs based on \l{https://bluetooth.org}{Bluetooth SIG standards}
+    should be retrieved via \l serviceClassUuids().
 
     \sa setServiceUuid(), attribute()
 */
 
-/*!
-    \fn QList<QBluetoothUuid> QBluetoothServiceInfo::serviceClassUuids() const
-
-    This is a convenience function. It is equivalent to calling
-    attribute(QBluetoothServiceInfo::ServiceClassIds).value<QList<QBluetoothUuid> >().
-
-    Returns a list of UUIDs describing the service classes that this service conforms to.
-
-    \sa attribute()
-*/
-
-
 /*!
     Construct a new invalid QBluetoothServiceInfo;
 */
@@ -513,6 +502,30 @@ QBluetoothServiceInfo::Sequence QBluetoothServiceInfo::protocolDescriptor(QBluet
     return d_ptr->protocolDescriptor(protocol);
 }
 
+/*!
+    Returns a list of UUIDs describing the service classes that this service conforms to.
+
+    This is a convenience function. It is equivalent to calling
+    attribute(QBluetoothServiceInfo::ServiceClassIds).value<QBluetoothServiceInfo::Sequence>()
+    and subsequently iterating over its QBluetoothUuid entries.
+
+    \sa attribute()
+*/
+QList<QBluetoothUuid> QBluetoothServiceInfo::serviceClassUuids() const
+{
+    QList<QBluetoothUuid> results;
+
+    const QVariant var = attribute(QBluetoothServiceInfo::ServiceClassIds);
+    if (!var.isValid())
+        return results;
+
+    const QBluetoothServiceInfo::Sequence seq = var.value<QBluetoothServiceInfo::Sequence>();
+    for (int i = 0; i < seq.count(); i++)
+        results.append(seq.at(i).value<QBluetoothUuid>());
+
+    return results;
+}
+
 /*!
     Makes a copy of the \a other and assigns it to this QBluetoothServiceInfo object.
     The two copies continue to share the same service and registration details.
