@@ -1,40 +1,32 @@
 /****************************************************************************
 **
-** Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
-** Contact: http://www.qt-project.org/legal
+** Copyright (C) 2015 The Qt Company Ltd.
+** Contact: http://www.qt.io/licensing/
 **
 ** This file is part of the QtBluetooth module of the Qt Toolkit.
 **
-** $QT_BEGIN_LICENSE:LGPL$
+** $QT_BEGIN_LICENSE:LGPL21$
 ** Commercial License Usage
 ** Licensees holding valid commercial Qt licenses may use this file in
 ** accordance with the commercial license agreement provided with the
 ** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and Digia.  For licensing terms and
-** conditions see http://qt.digia.com/licensing.  For further information
-** use the contact form at http://qt.digia.com/contact-us.
+** a written agreement between you and The Qt Company. For licensing terms
+** and conditions see http://www.qt.io/terms-conditions. For further
+** information use the contact form at http://www.qt.io/contact-us.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 2.1 as published by the Free Software
-** Foundation and appearing in the file LICENSE.LGPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU Lesser General Public License version 2.1 requirements
-** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
+** General Public License version 2.1 or version 3 as published by the Free
+** Software Foundation and appearing in the file LICENSE.LGPLv21 and
+** LICENSE.LGPLv3 included in the packaging of this file. Please review the
+** following information to ensure the GNU Lesser General Public License
+** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
+** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
-** In addition, as a special exception, Digia gives you certain additional
-** rights.  These rights are described in the Digia Qt LGPL Exception
+** As a special exception, The Qt Company gives you certain additional
+** rights. These rights are described in The Qt Company LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
-**
-**
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -45,6 +37,8 @@
 #include "bluez/manager_p.h"
 #include "bluez/adapter_p.h"
 #include "bluez/device_p.h"
+#include "bluez/objectmanager_p.h"
+#include <QtBluetooth/QBluetoothLocalDevice>
 #include "bluez/bluez_data_p.h"
 
 #include <qplatformdefs.h>
@@ -69,7 +63,8 @@ QBluetoothSocketPrivate::QBluetoothSocketPrivate()
       readNotifier(0),
       connectWriteNotifier(0),
       connecting(false),
-      discoveryAgent(0)
+      discoveryAgent(0),
+      lowEnergySocketType(0)
 {
 }
 
@@ -115,9 +110,9 @@ bool QBluetoothSocketPrivate::ensureNativeSocket(QBluetoothServiceInfo::Protocol
 
     Q_Q(QBluetoothSocket);
     readNotifier = new QSocketNotifier(socket, QSocketNotifier::Read);
-    QObject::connect(readNotifier, SIGNAL(activated(int)), q, SLOT(_q_readNotify()));
+    QObject::connect(readNotifier, SIGNAL(activated(int)), this, SLOT(_q_readNotify()));
     connectWriteNotifier = new QSocketNotifier(socket, QSocketNotifier::Write, q);
-    QObject::connect(connectWriteNotifier, SIGNAL(activated(int)), q, SLOT(_q_writeNotify()));
+    QObject::connect(connectWriteNotifier, SIGNAL(activated(int)), this, SLOT(_q_writeNotify()));
 
     connectWriteNotifier->setEnabled(false);
     readNotifier->setEnabled(false);
@@ -129,11 +124,10 @@ bool QBluetoothSocketPrivate::ensureNativeSocket(QBluetoothServiceInfo::Protocol
 void QBluetoothSocketPrivate::connectToService(const QBluetoothAddress &address, quint16 port, QIODevice::OpenMode openMode)
 {
     Q_Q(QBluetoothSocket);
-    Q_UNUSED(openMode);
     int result = -1;
 
     if (socket == -1 && !ensureNativeSocket(socketType)) {
-        errorString = QObject::tr("Unknown socket error");
+        errorString = QBluetoothSocket::tr("Unknown socket error");
         q->setSocketError(QBluetoothSocket::UnknownSocketError);
         return;
     }
@@ -156,7 +150,22 @@ void QBluetoothSocketPrivate::connectToService(const QBluetoothAddress &address,
 
         memset(&addr, 0, sizeof(addr));
         addr.l2_family = AF_BLUETOOTH;
-        addr.l2_psm = port;
+        // This is an ugly hack but the socket class does what's needed already.
+        // For L2CP GATT we need a channel rather than a socket and the LE address type
+        // We don't want to make this public API offering for now especially since
+        // only Linux (of all platforms supported by this library) supports this type
+        // of socket.
+
+#if defined(QT_BLUEZ_BLUETOOTH) && !defined(QT_BLUEZ_NO_BTLE)
+        if (lowEnergySocketType) {
+            addr.l2_cid = htobs(port);
+            addr.l2_bdaddr_type = lowEnergySocketType;
+        } else {
+            addr.l2_psm = htobs(port);
+        }
+#else
+        addr.l2_psm = htobs(port);
+#endif
 
         convertAddress(address.toUInt64(), addr.l2_bdaddr.b);
 
@@ -169,6 +178,7 @@ void QBluetoothSocketPrivate::connectToService(const QBluetoothAddress &address,
     if (result >= 0 || (result == -1 && errno == EINPROGRESS)) {
         connecting = true;
         q->setSocketState(QBluetoothSocket::ConnectingState);
+        q->setOpenMode(openMode);
     } else {
         errorString = qt_error_string(errno);
         q->setSocketError(QBluetoothSocket::UnknownSocketError);
@@ -222,8 +232,6 @@ void QBluetoothSocketPrivate::_q_writeNotify()
     }
 }
 
-// TODO: move to private backend?
-
 void QBluetoothSocketPrivate::_q_readNotify()
 {
     Q_Q(QBluetoothSocket);
@@ -269,23 +277,8 @@ QString QBluetoothSocketPrivate::localName() const
     if (address.isNull())
         return QString();
 
-    OrgBluezManagerInterface manager(QLatin1String("org.bluez"), QLatin1String("/"),
-                                     QDBusConnection::systemBus());
-
-    QDBusPendingReply<QDBusObjectPath> reply = manager.FindAdapter(address.toString());
-    reply.waitForFinished();
-    if (reply.isError())
-        return QString();
-
-    OrgBluezAdapterInterface adapter(QLatin1String("org.bluez"), reply.value().path(),
-                                     QDBusConnection::systemBus());
-
-    QDBusPendingReply<QVariantMap> properties = adapter.GetProperties();
-    properties.waitForFinished();
-    if (properties.isError())
-        return QString();
-
-    return properties.value().value(QLatin1String("Name")).toString();
+    QBluetoothLocalDevice device(address);
+    return device.name();
 }
 
 QBluetoothAddress QBluetoothSocketPrivate::localAddress() const
@@ -360,38 +353,60 @@ QString QBluetoothSocketPrivate::peerName() const
     const QString peerAddress = QBluetoothAddress(bdaddr).toString();
     const QString localAdapter = localAddress().toString();
 
-    OrgBluezManagerInterface manager(QLatin1String("org.bluez"), QLatin1String("/"),
-                                     QDBusConnection::systemBus());
-
-    QDBusPendingReply<QDBusObjectPath> reply = manager.FindAdapter(localAdapter);
-    reply.waitForFinished();
-    if (reply.isError())
-        return QString();
-
-    OrgBluezAdapterInterface adapter(QLatin1String("org.bluez"), reply.value().path(),
-                                     QDBusConnection::systemBus());
-
-    QDBusPendingReply<QDBusObjectPath> deviceObjectPath = adapter.CreateDevice(peerAddress);
-    deviceObjectPath.waitForFinished();
-    if (deviceObjectPath.isError()) {
-        if (deviceObjectPath.error().name() != QLatin1String("org.bluez.Error.AlreadyExists"))
+    if (isBluez5()) {
+        OrgFreedesktopDBusObjectManagerInterface manager(QStringLiteral("org.bluez"),
+                                                         QStringLiteral("/"),
+                                                         QDBusConnection::systemBus());
+        QDBusPendingReply<ManagedObjectList> reply = manager.GetManagedObjects();
+        reply.waitForFinished();
+        if (reply.isError())
             return QString();
 
-        deviceObjectPath = adapter.FindDevice(peerAddress);
+        foreach (const QDBusObjectPath &path, reply.value().keys()) {
+            const InterfaceList ifaceList = reply.value().value(path);
+            foreach (const QString &iface, ifaceList.keys()) {
+                if (iface == QStringLiteral("org.bluez.Device1")) {
+                    if (ifaceList.value(iface).value(QStringLiteral("Address")).toString()
+                            == peerAddress)
+                        return ifaceList.value(iface).value(QStringLiteral("Alias")).toString();
+                }
+            }
+        }
+        return QString();
+    } else {
+        OrgBluezManagerInterface manager(QStringLiteral("org.bluez"), QStringLiteral("/"),
+                                         QDBusConnection::systemBus());
+
+        QDBusPendingReply<QDBusObjectPath> reply = manager.FindAdapter(localAdapter);
+        reply.waitForFinished();
+        if (reply.isError())
+            return QString();
+
+        OrgBluezAdapterInterface adapter(QStringLiteral("org.bluez"), reply.value().path(),
+                                         QDBusConnection::systemBus());
+
+        QDBusPendingReply<QDBusObjectPath> deviceObjectPath = adapter.CreateDevice(peerAddress);
         deviceObjectPath.waitForFinished();
-        if (deviceObjectPath.isError())
+        if (deviceObjectPath.isError()) {
+            if (deviceObjectPath.error().name() != QStringLiteral("org.bluez.Error.AlreadyExists"))
+                return QString();
+
+            deviceObjectPath = adapter.FindDevice(peerAddress);
+            deviceObjectPath.waitForFinished();
+            if (deviceObjectPath.isError())
+                return QString();
+        }
+
+        OrgBluezDeviceInterface device(QStringLiteral("org.bluez"), deviceObjectPath.value().path(),
+                                       QDBusConnection::systemBus());
+
+        QDBusPendingReply<QVariantMap> properties = device.GetProperties();
+        properties.waitForFinished();
+        if (properties.isError())
             return QString();
+
+        return properties.value().value(QStringLiteral("Alias")).toString();
     }
-
-    OrgBluezDeviceInterface device(QLatin1String("org.bluez"), deviceObjectPath.value().path(),
-                                   QDBusConnection::systemBus());
-
-    QDBusPendingReply<QVariantMap> properties = device.GetProperties();
-    properties.waitForFinished();
-    if (properties.isError())
-        return QString();
-
-    return properties.value().value(QLatin1String("Alias")).toString();
 }
 
 QBluetoothAddress QBluetoothSocketPrivate::peerAddress() const
@@ -466,7 +481,7 @@ qint64 QBluetoothSocketPrivate::writeData(const char *data, qint64 maxSize)
 
         if(txBuffer.size() == 0) {
             connectWriteNotifier->setEnabled(true);
-            QMetaObject::invokeMethod(q, "_q_writeNotify", Qt::QueuedConnection);
+            QMetaObject::invokeMethod(this, "_q_writeNotify", Qt::QueuedConnection);
         }
 
         char *txbuf = txBuffer.reserve(maxSize);
@@ -496,20 +511,10 @@ qint64 QBluetoothSocketPrivate::readData(char *data, qint64 maxSize)
 
 void QBluetoothSocketPrivate::close()
 {
-    Q_Q(QBluetoothSocket);
-
-    // Only go through closing if the socket was fully opened
-    if(state == QBluetoothSocket::ConnectedState)
-        q->setSocketState(QBluetoothSocket::ClosingState);
-
-    if(txBuffer.size() > 0 &&
-       state == QBluetoothSocket::ClosingState){
+    if (txBuffer.size() > 0)
         connectWriteNotifier->setEnabled(true);
-    }
-    else {
+    else
         abort();
-    }
-
 }
 
 bool QBluetoothSocketPrivate::setSocketDescriptor(int socketDescriptor, QBluetoothServiceInfo::Protocol socketType_,
@@ -530,9 +535,9 @@ bool QBluetoothSocketPrivate::setSocketDescriptor(int socketDescriptor, QBluetoo
         fcntl(socket, F_SETFL, flags | O_NONBLOCK);
 
     readNotifier = new QSocketNotifier(socket, QSocketNotifier::Read);
-    QObject::connect(readNotifier, SIGNAL(activated(int)), q, SLOT(_q_readNotify()));
+    QObject::connect(readNotifier, SIGNAL(activated(int)), this, SLOT(_q_readNotify()));
     connectWriteNotifier = new QSocketNotifier(socket, QSocketNotifier::Write, q);
-    QObject::connect(connectWriteNotifier, SIGNAL(activated(int)), q, SLOT(_q_writeNotify()));
+    QObject::connect(connectWriteNotifier, SIGNAL(activated(int)), this, SLOT(_q_writeNotify()));
 
     q->setSocketState(socketState);
     q->setOpenMode(openMode);
