@@ -1,40 +1,32 @@
 /****************************************************************************
 **
-** Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
-** Contact: http://www.qt-project.org/legal
+** Copyright (C) 2015 The Qt Company Ltd.
+** Contact: http://www.qt.io/licensing/
 **
 ** This file is part of the QtBluetooth module of the Qt Toolkit.
 **
-** $QT_BEGIN_LICENSE:LGPL$
+** $QT_BEGIN_LICENSE:LGPL21$
 ** Commercial License Usage
 ** Licensees holding valid commercial Qt licenses may use this file in
 ** accordance with the commercial license agreement provided with the
 ** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and Digia.  For licensing terms and
-** conditions see http://qt.digia.com/licensing.  For further information
-** use the contact form at http://qt.digia.com/contact-us.
+** a written agreement between you and The Qt Company. For licensing terms
+** and conditions see http://www.qt.io/terms-conditions. For further
+** information use the contact form at http://www.qt.io/contact-us.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 2.1 as published by the Free Software
-** Foundation and appearing in the file LICENSE.LGPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU Lesser General Public License version 2.1 requirements
-** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
+** General Public License version 2.1 or version 3 as published by the Free
+** Software Foundation and appearing in the file LICENSE.LGPLv21 and
+** LICENSE.LGPLv3 included in the packaging of this file. Please review the
+** following information to ensure the GNU Lesser General Public License
+** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
+** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
-** In addition, as a special exception, Digia gives you certain additional
-** rights.  These rights are described in the Digia Qt LGPL Exception
+** As a special exception, The Qt Company gives you certain additional
+** rights. These rights are described in The Qt Company LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
-**
-**
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -60,8 +52,10 @@
 #endif
 #ifdef QT_ANDROID_BLUETOOTH
 #include <QtAndroidExtras/QAndroidJniObject>
+#include <QtCore/QPointer>
 #include "android/inputstreamthread_p.h"
 #include <jni.h>
+class WorkerThread;
 #endif
 
 #ifndef QPRIVATELINEARBUFFER_BUFFERSIZE
@@ -89,14 +83,10 @@ public:
 class QBluetoothSocket;
 class QBluetoothServiceDiscoveryAgent;
 
-class QBluetoothSocketPrivate
-#if defined(QT_QNX_BLUETOOTH) || defined(QT_ANDROID_BLUETOOTH)
-: public QObject
+#ifndef QT_OSX_BLUETOOTH
+class QBluetoothSocketPrivate : public QObject
 {
     Q_OBJECT
-#else
-{
-#endif
     Q_DECLARE_PUBLIC(QBluetoothSocket)
     friend class QBluetoothServerPrivate;
 
@@ -106,18 +96,14 @@ public:
     ~QBluetoothSocketPrivate();
 
 //On QNX and Android we connect using the uuid not the port
-#if defined(QT_QNX_BLUETOOTH)
-    void connectToService(const QBluetoothAddress &address, const QBluetoothUuid &uuid, QIODevice::OpenMode openMode);
-#elif defined(QT_ANDROID_BLUETOOTH)
+#if defined(QT_QNX_BLUETOOTH) || defined(QT_ANDROID_BLUETOOTH)
     void connectToService(const QBluetoothAddress &address, const QBluetoothUuid &uuid,
-                          QIODevice::OpenMode openMode, int fallbackServiceChannel = 1);
-    bool fallBackConnect(QAndroidJniObject uuid, int channel);
+                          QIODevice::OpenMode openMode);
 #else
     void connectToService(const QBluetoothAddress &address, quint16 port, QIODevice::OpenMode openMode);
 #endif
 #ifdef QT_ANDROID_BLUETOOTH
-    void connectToServiceConc(const QBluetoothAddress &address, const QBluetoothUuid &uuid,
-                              QIODevice::OpenMode openMode, int fallbackServiceChannel = 1);
+    bool fallBackConnect(QAndroidJniObject uuid, int channel);
 #endif
 
 
@@ -171,12 +157,6 @@ public:
 //    qint64 rxOffset;
     QString errorString;
 
-    // private slots
-    void _q_readNotify();
-    void _q_writeNotify();
-    void _q_serviceDiscovered(const QBluetoothServiceInfo &service);
-    void _q_discoveryFinished();
-
 #ifdef QT_ANDROID_BLUETOOTH
     QAndroidJniObject adapter;
     QAndroidJniObject socketObject;
@@ -185,9 +165,24 @@ public:
     QAndroidJniObject outputStream;
     InputStreamThread *inputThread;
 
-private Q_SLOTS:
+public slots:
+    void socketConnectSuccess(const QAndroidJniObject &socket);
+    void defaultSocketConnectFailed(const QAndroidJniObject & socket,
+                                    const QAndroidJniObject &targetUuid);
+    void fallbackSocketConnectFailed(const QAndroidJniObject &socket,
+                                     const QAndroidJniObject &targetUuid);
     void inputThreadError(int errorCode);
 
+signals:
+    void connectJavaSocket();
+    void closeJavaSocket();
+
+#endif
+
+#if defined(QT_QNX_BLUETOOTH) || defined(QT_BLUEZ_BLUETOOTH)
+private slots:
+    void _q_readNotify();
+    void _q_writeNotify();
 #endif
 
 protected:
@@ -199,12 +194,32 @@ private:
     QBluetoothUuid m_uuid;
     bool isServerSocket;
 
-private Q_SLOTS:
+private slots:
     void controlReply(ppsResult result);
     void controlEvent(ppsResult result);
 #endif
+
+#ifdef QT_BLUEZ_BLUETOOTH
+public:
+    quint8 lowEnergySocketType;
+#endif
 };
 
+#else // QT_OSX_BLUETOOTH
+
+// QBluetoothSocketPrivate on OS X can not contain
+// Q_OBJECT (moc does not parse Objective-C syntax).
+// But QBluetoothSocket still requires QMetaObject::invokeMethod
+// to work. Here's the trick:
+class QBluetoothSocketPrivateBase : public QObject
+{
+// The most important part of it:
+    Q_OBJECT
+public slots:
+    virtual void _q_writeNotify() = 0;
+};
+
+#endif // QT_OSX_BLUETOOTH
 
 static inline void convertAddress(quint64 from, quint8 (&to)[6])
 {
@@ -228,4 +243,5 @@ static inline void convertAddress(quint8 (&from)[6], quint64 &to)
 
 QT_END_NAMESPACE
 
+
 #endif
