@@ -1,41 +1,33 @@
 /***************************************************************************
 **
 ** Copyright (C) 2013 Research In Motion
-** Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
-** Contact: http://www.qt-project.org/legal
+** Copyright (C) 2015 The Qt Company Ltd.
+** Contact: http://www.qt.io/licensing/
 **
 ** This file is part of the QtBluetooth module of the Qt Toolkit.
 **
-** $QT_BEGIN_LICENSE:LGPL$
+** $QT_BEGIN_LICENSE:LGPL21$
 ** Commercial License Usage
 ** Licensees holding valid commercial Qt licenses may use this file in
 ** accordance with the commercial license agreement provided with the
 ** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and Digia.  For licensing terms and
-** conditions see http://qt.digia.com/licensing.  For further information
-** use the contact form at http://qt.digia.com/contact-us.
+** a written agreement between you and The Qt Company. For licensing terms
+** and conditions see http://www.qt.io/terms-conditions. For further
+** information use the contact form at http://www.qt.io/contact-us.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 2.1 as published by the Free Software
-** Foundation and appearing in the file LICENSE.LGPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU Lesser General Public License version 2.1 requirements
-** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
+** General Public License version 2.1 or version 3 as published by the Free
+** Software Foundation and appearing in the file LICENSE.LGPLv21 and
+** LICENSE.LGPLv3 included in the packaging of this file. Please review the
+** following information to ensure the GNU Lesser General Public License
+** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
+** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
-** In addition, as a special exception, Digia gives you certain additional
-** rights.  These rights are described in the Digia Qt LGPL Exception
+** As a special exception, The Qt Company gives you certain additional
+** rights. These rights are described in The Qt Company LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
-**
-**
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -52,6 +44,7 @@
 
 #include "qnx/ppshelpers_p.h"
 #include <QSocketNotifier>
+#include <QtCore/QVector>
 
 #include <QtCore/private/qcore_unix_p.h>
 
@@ -72,6 +65,15 @@ QBluetoothTransferReplyQnx::QBluetoothTransferReplyQnx(QIODevice *input, const Q
 {
     setRequest(request);
     setManager(parent);
+
+    if (!input) {
+        qCWarning(QT_BT_QNX) << "Invalid input device (null)";
+        m_errorStr = QBluetoothTransferReply::tr("Invalid input device (null)");
+        m_error = QBluetoothTransferReply::FileNotFoundError;
+        m_finished = true;
+        return;
+    }
+
     ppsRegisterControl();
     //qsrand(QTime::currentTime().msec());
     //m_agent_path = agentPath;
@@ -110,20 +112,22 @@ bool QBluetoothTransferReplyQnx::start()
             file.remove();
         }
         else if (directory.exists(appName) && busy) {
-            m_errorStr = QBluetoothTransferReply::tr("Resurce busy.");
+            m_errorStr = QBluetoothTransferReply::tr("Resource busy.");
             m_error = QBluetoothTransferReply::ResourceBusyError;
             m_finished = true;
             m_running = false;
-            Q_EMIT finished(this);
+            emit QBluetoothTransferReply::error(m_error);
+            emit finished(this);
             return false;
         }
         if (!source->isReadable()) {
-            m_errorStr = QBluetoothTransferReply::tr("QIODevice cannot be read."
+            m_errorStr = QBluetoothTransferReply::tr("QIODevice cannot be read. "
                                                      "Make sure it is open for reading.");
             m_error = QBluetoothTransferReply::IODeviceNotReadableError;
             m_finished = true;
             m_running = false;
-            Q_EMIT finished(this);
+            emit QBluetoothTransferReply::error(m_error);
+            emit finished(this);
             return false;
         }
         QString fileName = agentPath + QStringLiteral("Qt5OPP_tmp");
@@ -142,7 +146,8 @@ bool QBluetoothTransferReplyQnx::start()
             m_error = QBluetoothTransferReply::FileNotFoundError;
             m_finished = true;
             m_running = false;
-            QMetaObject::invokeMethod(this, "finished", Qt::QueuedConnection, Q_ARG(QBluetoothTransferReply*, this));
+            emit QBluetoothTransferReply::error(m_error);
+            emit finished(this);
             return false;
         }
         if (request().address().isNull()) {
@@ -150,7 +155,8 @@ bool QBluetoothTransferReplyQnx::start()
             m_error = QBluetoothTransferReply::HostNotFoundError;
             m_finished = true;
             m_running = false;
-            QMetaObject::invokeMethod(this, "finished", Qt::QueuedConnection, Q_ARG(QBluetoothTransferReply*, this));
+            emit QBluetoothTransferReply::error(m_error);
+            emit finished(this);
             return false;
         }
         startOPP(file->fileName());
@@ -160,15 +166,14 @@ bool QBluetoothTransferReplyQnx::start()
 
 bool QBluetoothTransferReplyQnx::copyToTempFile(QIODevice *to, QIODevice *from)
 {
-    char *block = new char[4096];
+    QVector<char> block(4096);
     int size;
 
-    while ((size = from->read(block, 4096)) > 0) {
-        if (size != to->write(block, size))
+    while ((size = from->read(block.data(), block.size())) > 0) {
+        if (size != to->write(block.data(), size))
             return false;
     }
 
-    delete[] block;
     return true;
 }
 
@@ -200,6 +205,8 @@ void QBluetoothTransferReplyQnx::controlReply(ppsResult result)
     if (!result.errorMsg.isEmpty()) {
         m_errorStr = result.errorMsg;
         m_error = QBluetoothTransferReply::UnknownError;
+        emit QBluetoothTransferReply::error(m_error);
+        emit finished(this);
     }
 }
 
@@ -222,8 +229,9 @@ void QBluetoothTransferReplyQnx::controlEvent(ppsResult result)
 //        } else {
         m_errorStr = result.errorMsg;
         m_error = QBluetoothTransferReply::UnknownError;
+        emit QBluetoothTransferReply::error(m_error);
 //      }
-        Q_EMIT finished(this);
+        emit finished(this);
     } else if (result.msg == QStringLiteral("opp_update")) {
         bool ok;
         qint64 sentBytes = result.dat.at(result.dat.indexOf(QStringLiteral("sent")) + 1).toDouble(&ok);
@@ -237,13 +245,13 @@ void QBluetoothTransferReplyQnx::controlEvent(ppsResult result)
             return;
         }
         qCDebug(QT_BT_QNX) << "opp update" << sentBytes << totalBytes;
-        Q_EMIT transferProgress(sentBytes, totalBytes);
+        emit transferProgress(sentBytes, totalBytes);
     } else if (result.msg == QStringLiteral("opp_complete")) {
         qCDebug(QT_BT_QNX) << "opp complete";
         removeTempFile();
         m_finished = true;
         m_running = false;
-        Q_EMIT finished(this);
+        emit finished(this);
     }
 }
 
