@@ -1,40 +1,32 @@
 /****************************************************************************
 **
-** Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
-** Contact: http://www.qt-project.org/legal
+** Copyright (C) 2015 The Qt Company Ltd.
+** Contact: http://www.qt.io/licensing/
 **
 ** This file is part of the QtNfc module of the Qt Toolkit.
 **
-** $QT_BEGIN_LICENSE:LGPL$
+** $QT_BEGIN_LICENSE:LGPL21$
 ** Commercial License Usage
 ** Licensees holding valid commercial Qt licenses may use this file in
 ** accordance with the commercial license agreement provided with the
 ** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and Digia.  For licensing terms and
-** conditions see http://qt.digia.com/licensing.  For further information
-** use the contact form at http://qt.digia.com/contact-us.
+** a written agreement between you and The Qt Company. For licensing terms
+** and conditions see http://www.qt.io/terms-conditions. For further
+** information use the contact form at http://www.qt.io/contact-us.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 2.1 as published by the Free Software
-** Foundation and appearing in the file LICENSE.LGPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU Lesser General Public License version 2.1 requirements
-** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
+** General Public License version 2.1 or version 3 as published by the Free
+** Software Foundation and appearing in the file LICENSE.LGPLv21 and
+** LICENSE.LGPLv3 included in the packaging of this file. Please review the
+** following information to ensure the GNU Lesser General Public License
+** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
+** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
-** In addition, as a special exception, Digia gives you certain additional
-** rights.  These rights are described in the Digia Qt LGPL Exception
+** As a special exception, The Qt Company gives you certain additional
+** rights. These rights are described in The Qt Company LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
-**
-**
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -46,6 +38,8 @@
 #include "qnearfieldmanager_simulator_p.h"
 #elif defined(QNX_NFC)
 #include "qnearfieldmanager_qnx_p.h"
+#elif defined(NEARD_NFC)
+#include "qnearfieldmanager_neard_p.h"
 #else
 #include "qnearfieldmanagerimpl_p.h"
 #endif
@@ -61,6 +55,7 @@ QT_BEGIN_NAMESPACE
 
     \ingroup connectivity-nfc
     \inmodule QtNfc
+    \since 5.2
 
     NFC Forum devices support two modes of communications.  The first mode, peer-to-peer
     communications, is used to communicate between two NFC Forum devices.  The second mode,
@@ -119,6 +114,14 @@ QT_BEGIN_NAMESPACE
         </filter>
     </invoke-target>
     \endcode
+
+    \section3 NFC on Linux
+    The \l{https://01.org/linux-nfc}{Linux NFC project} provides software to support NFC on Linux platforms.
+    The neard daemon will allow access to the supported hardware via DBus interfaces. QtNfc requires neard
+    version 0.14 which can be built from source or installed via the appropriate Linux package manager. Not
+    all API features are currently supported.
+    To allow QtNfc to access the DBus interfaces the neard daemon has to be running. In case of problems
+    debug output can be enabled by enabling categorized logging for 'qt.nfc.neard'.
 */
 
 /*!
@@ -220,6 +223,8 @@ bool QNearFieldManager::isAvailable() const
     successfully started; otherwise returns false. Causes the targetDetected() signal to be emitted
     when a target is within proximity.
     \sa stopTargetDetection()
+
+    \note For platforms using neard: target detection will stop as soon as a tag has been detected.
 */
 bool QNearFieldManager::startTargetDetection()
 {
@@ -283,6 +288,8 @@ static QMetaMethod methodForSignature(QObject *object, const char *method)
 
     \note The \e target parameter of \a method may not be available on all platforms, in which case
     \e target will be 0.
+
+    \note On platforms using neard registering message handlers is not supported.
 */
 
 int QNearFieldManager::registerNdefMessageHandler(QNdefRecord::TypeNameFormat typeNameFormat,
