@@ -1,46 +1,39 @@
 /****************************************************************************
 **
-** Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
-** Contact: http://www.qt-project.org/legal
+** Copyright (C) 2015 The Qt Company Ltd.
+** Contact: http://www.qt.io/licensing/
 **
 ** This file is part of the QtBluetooth module of the Qt Toolkit.
 **
-** $QT_BEGIN_LICENSE:LGPL$
+** $QT_BEGIN_LICENSE:LGPL21$
 ** Commercial License Usage
 ** Licensees holding valid commercial Qt licenses may use this file in
 ** accordance with the commercial license agreement provided with the
 ** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and Digia.  For licensing terms and
-** conditions see http://qt.digia.com/licensing.  For further information
-** use the contact form at http://qt.digia.com/contact-us.
+** a written agreement between you and The Qt Company. For licensing terms
+** and conditions see http://www.qt.io/terms-conditions. For further
+** information use the contact form at http://www.qt.io/contact-us.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 2.1 as published by the Free Software
-** Foundation and appearing in the file LICENSE.LGPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU Lesser General Public License version 2.1 requirements
-** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
+** General Public License version 2.1 or version 3 as published by the Free
+** Software Foundation and appearing in the file LICENSE.LGPLv21 and
+** LICENSE.LGPLv3 included in the packaging of this file. Please review the
+** following information to ensure the GNU Lesser General Public License
+** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
+** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
-** In addition, as a special exception, Digia gives you certain additional
-** rights.  These rights are described in the Digia Qt LGPL Exception
+** As a special exception, The Qt Company gives you certain additional
+** rights. These rights are described in The Qt Company LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
-**
-**
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
 
 #include <QtTest/QtTest>
 
+#include <QScopedPointer>
 #include <QDebug>
 
 #include <qbluetoothaddress.h>
@@ -52,6 +45,7 @@ QT_USE_NAMESPACE
 
 Q_DECLARE_METATYPE(QBluetoothDeviceInfo::ServiceClasses)
 Q_DECLARE_METATYPE(QBluetoothDeviceInfo::MajorDeviceClass)
+Q_DECLARE_METATYPE(QBluetoothDeviceInfo::CoreConfiguration)
 
 class tst_QBluetoothDeviceInfo : public QObject
 {
@@ -73,6 +67,8 @@ private slots:
     void tst_serviceUuids();
 
     void tst_cached();
+
+    void tst_flags();
 };
 
 tst_QBluetoothDeviceInfo::tst_QBluetoothDeviceInfo()
@@ -85,8 +81,8 @@ tst_QBluetoothDeviceInfo::~tst_QBluetoothDeviceInfo()
 
 void tst_QBluetoothDeviceInfo::initTestCase()
 {
-    qRegisterMetaType<QBluetoothDeviceInfo::ServiceClasses>("QBluetoothDeviceInfo::ServiceClasses");
-    qRegisterMetaType<QBluetoothDeviceInfo::MajorDeviceClass>("QBluetoothDeviceInfo::MajorDeviceClass");
+    qRegisterMetaType<QBluetoothDeviceInfo::ServiceClasses>();
+    qRegisterMetaType<QBluetoothDeviceInfo::MajorDeviceClass>();
     // start Bluetooth if not started
     QBluetoothLocalDevice *device = new QBluetoothLocalDevice();
     device->powerOn();
@@ -101,6 +97,11 @@ void tst_QBluetoothDeviceInfo::tst_construction_data()
     QTest::addColumn<QBluetoothDeviceInfo::ServiceClasses>("serviceClasses");
     QTest::addColumn<QBluetoothDeviceInfo::MajorDeviceClass>("majorDeviceClass");
     QTest::addColumn<quint8>("minorDeviceClass");
+    QTest::addColumn<QBluetoothDeviceInfo::CoreConfiguration>("coreConfiguration");
+    // On OS X and iOS there are no real addresses
+    // with Core Bluetooth, only 'uuids' (128-bit) generated by Apple instead.
+    QTest::addColumn<QBluetoothUuid>("deviceUuid");
+    const QBluetoothUuid leDeviceUuid(QString("6C903349-31E2-40EF-826B-1E62C0D884E2"));
 
     // bits 12-8 Major
     // bits 7-2 Minor
@@ -110,120 +111,168 @@ void tst_QBluetoothDeviceInfo::tst_construction_data()
         << quint32(0x000000)
         << QBluetoothDeviceInfo::ServiceClasses(QBluetoothDeviceInfo::NoService)
         << QBluetoothDeviceInfo::MiscellaneousDevice
-        << quint8(QBluetoothDeviceInfo::UncategorizedMiscellaneous);
+        << quint8(QBluetoothDeviceInfo::UncategorizedMiscellaneous)
+        << QBluetoothDeviceInfo::BaseRateCoreConfiguration
+        << leDeviceUuid;
     QTest::newRow("0x000100 COD") << QBluetoothAddress("000000000000") << "My Bluetooth Device"
         << quint32(0x000100)
         << QBluetoothDeviceInfo::ServiceClasses(QBluetoothDeviceInfo::NoService)
         << QBluetoothDeviceInfo::ComputerDevice
-        << quint8(QBluetoothDeviceInfo::UncategorizedComputer);
+        << quint8(QBluetoothDeviceInfo::UncategorizedComputer)
+        << QBluetoothDeviceInfo::BaseRateCoreConfiguration
+        << leDeviceUuid;
     QTest::newRow("0x000104 COD") << QBluetoothAddress("000000000000") << "My Bluetooth Device"
         << quint32(0x000104)
         << QBluetoothDeviceInfo::ServiceClasses(QBluetoothDeviceInfo::NoService)
         << QBluetoothDeviceInfo::ComputerDevice
-        << quint8(QBluetoothDeviceInfo::DesktopComputer);
+        << quint8(QBluetoothDeviceInfo::DesktopComputer)
+        << QBluetoothDeviceInfo::BaseRateAndLowEnergyCoreConfiguration
+        << leDeviceUuid;
     QTest::newRow("0x000118 COD") << QBluetoothAddress("000000000000") << "My Bluetooth Device"
         << quint32(0x000118)
         << QBluetoothDeviceInfo::ServiceClasses(QBluetoothDeviceInfo::NoService)
         << QBluetoothDeviceInfo::ComputerDevice
-        << quint8(QBluetoothDeviceInfo::WearableComputer);
+        << quint8(QBluetoothDeviceInfo::WearableComputer)
+        << QBluetoothDeviceInfo::BaseRateAndLowEnergyCoreConfiguration
+        << leDeviceUuid;
     QTest::newRow("0x000200 COD") << QBluetoothAddress("000000000000") << "My Bluetooth Device" << quint32(0x000200)
         << QBluetoothDeviceInfo::ServiceClasses(QBluetoothDeviceInfo::NoService)
         << QBluetoothDeviceInfo::PhoneDevice
-        << quint8(QBluetoothDeviceInfo::UncategorizedPhone);
+        << quint8(QBluetoothDeviceInfo::UncategorizedPhone)
+        << QBluetoothDeviceInfo::BaseRateAndLowEnergyCoreConfiguration
+        << leDeviceUuid;
     QTest::newRow("0x000204 COD") << QBluetoothAddress("000000000000") << "My Bluetooth Device"
         << quint32(0x000204)
         << QBluetoothDeviceInfo::ServiceClasses(QBluetoothDeviceInfo::NoService)
         << QBluetoothDeviceInfo::PhoneDevice
-        << quint8(QBluetoothDeviceInfo::CellularPhone);
+        << quint8(QBluetoothDeviceInfo::CellularPhone)
+        << QBluetoothDeviceInfo::BaseRateAndLowEnergyCoreConfiguration
+        << leDeviceUuid;
     QTest::newRow("0x000214 COD") << QBluetoothAddress("000000000000") << "My Bluetooth Device" << quint32(0x000214)
         << QBluetoothDeviceInfo::ServiceClasses(QBluetoothDeviceInfo::NoService)
         << QBluetoothDeviceInfo::PhoneDevice
-        << quint8(QBluetoothDeviceInfo::CommonIsdnAccessPhone);
+        << quint8(QBluetoothDeviceInfo::CommonIsdnAccessPhone)
+        << QBluetoothDeviceInfo::BaseRateAndLowEnergyCoreConfiguration
+        << leDeviceUuid;
     QTest::newRow("0x000300 COD") << QBluetoothAddress("000000000000") << "My Bluetooth Device"
         << quint32(0x000300)
         << QBluetoothDeviceInfo::ServiceClasses(QBluetoothDeviceInfo::NoService)
         << QBluetoothDeviceInfo::LANAccessDevice
-        << quint8(QBluetoothDeviceInfo::NetworkFullService);
+        << quint8(QBluetoothDeviceInfo::NetworkFullService)
+        << QBluetoothDeviceInfo::BaseRateAndLowEnergyCoreConfiguration
+        << leDeviceUuid;
     QTest::newRow("0x000320 COD") << QBluetoothAddress("000000000000") << "My Bluetooth Device"
         << quint32(0x000320)
         << QBluetoothDeviceInfo::ServiceClasses(QBluetoothDeviceInfo::NoService)
         << QBluetoothDeviceInfo::LANAccessDevice
-        << quint8(QBluetoothDeviceInfo::NetworkLoadFactorOne);
+        << quint8(QBluetoothDeviceInfo::NetworkLoadFactorOne)
+        << QBluetoothDeviceInfo::BaseRateAndLowEnergyCoreConfiguration
+        << leDeviceUuid;
     QTest::newRow("0x0003E0 COD") << QBluetoothAddress("000000000000") << "My Bluetooth Device"
         << quint32(0x0003E0)
         << QBluetoothDeviceInfo::ServiceClasses(QBluetoothDeviceInfo::NoService)
         << QBluetoothDeviceInfo::LANAccessDevice
-        << quint8(QBluetoothDeviceInfo::NetworkNoService);
+        << quint8(QBluetoothDeviceInfo::NetworkNoService)
+        << QBluetoothDeviceInfo::BaseRateAndLowEnergyCoreConfiguration
+        << leDeviceUuid;
     QTest::newRow("0x000400 COD") << QBluetoothAddress("000000000000") << "My Bluetooth Device"
         << quint32(0x000400)
         << QBluetoothDeviceInfo::ServiceClasses(QBluetoothDeviceInfo::NoService)
         << QBluetoothDeviceInfo::AudioVideoDevice
-        << quint8(QBluetoothDeviceInfo::UncategorizedAudioVideoDevice);
+        << quint8(QBluetoothDeviceInfo::UncategorizedAudioVideoDevice)
+        << QBluetoothDeviceInfo::BaseRateAndLowEnergyCoreConfiguration
+        << leDeviceUuid;
     QTest::newRow("0x000448 COD") << QBluetoothAddress("000000000000") << "My Bluetooth Device"
         << quint32(0x000448)
         << QBluetoothDeviceInfo::ServiceClasses(QBluetoothDeviceInfo::NoService)
         << QBluetoothDeviceInfo::AudioVideoDevice
-        << quint8(QBluetoothDeviceInfo::GamingDevice);
+        << quint8(QBluetoothDeviceInfo::GamingDevice)
+        << QBluetoothDeviceInfo::BaseRateAndLowEnergyCoreConfiguration
+        << leDeviceUuid;
     QTest::newRow("0x000500 COD") << QBluetoothAddress("000000000000") << "My Bluetooth Device"
         << quint32(0x000500)
         << QBluetoothDeviceInfo::ServiceClasses(QBluetoothDeviceInfo::NoService)
         << QBluetoothDeviceInfo::PeripheralDevice
-        << quint8(QBluetoothDeviceInfo::UncategorizedPeripheral);
+        << quint8(QBluetoothDeviceInfo::UncategorizedPeripheral)
+        << QBluetoothDeviceInfo::BaseRateAndLowEnergyCoreConfiguration
+        << leDeviceUuid;
     QTest::newRow("0x0005D8 COD") << QBluetoothAddress("000000000000") << "My Bluetooth Device"
         << quint32(0x0005D8)
         << QBluetoothDeviceInfo::ServiceClasses(QBluetoothDeviceInfo::NoService)
         << QBluetoothDeviceInfo::PeripheralDevice
-        << quint8(QBluetoothDeviceInfo::KeyboardWithPointingDevicePeripheral | QBluetoothDeviceInfo::CardReaderPeripheral);
+        << quint8(QBluetoothDeviceInfo::KeyboardWithPointingDevicePeripheral | QBluetoothDeviceInfo::CardReaderPeripheral)
+        << QBluetoothDeviceInfo::BaseRateAndLowEnergyCoreConfiguration
+        << leDeviceUuid;
     QTest::newRow("0x000600 COD") << QBluetoothAddress("000000000000") << "My Bluetooth Device"
         << quint32(0x000600)
         << QBluetoothDeviceInfo::ServiceClasses(QBluetoothDeviceInfo::NoService)
         << QBluetoothDeviceInfo::ImagingDevice
-        << quint8(QBluetoothDeviceInfo::UncategorizedImagingDevice);
+        << quint8(QBluetoothDeviceInfo::UncategorizedImagingDevice)
+        << QBluetoothDeviceInfo::BaseRateAndLowEnergyCoreConfiguration
+        << leDeviceUuid;
     QTest::newRow("0x000680 COD") << QBluetoothAddress("000000000000") << "My Bluetooth Device"
         << quint32(0x000680)
         << QBluetoothDeviceInfo::ServiceClasses(QBluetoothDeviceInfo::NoService)
         << QBluetoothDeviceInfo::ImagingDevice
-        << quint8(QBluetoothDeviceInfo::ImagePrinter);
+        << quint8(QBluetoothDeviceInfo::ImagePrinter)
+        << QBluetoothDeviceInfo::LowEnergyCoreConfiguration
+        << leDeviceUuid;
     QTest::newRow("0x000700 COD") << QBluetoothAddress("000000000000") << "My Bluetooth Device"
         << quint32(0x000700)
         << QBluetoothDeviceInfo::ServiceClasses(QBluetoothDeviceInfo::NoService)
         << QBluetoothDeviceInfo::WearableDevice
-        << quint8(QBluetoothDeviceInfo::UncategorizedWearableDevice);
+        << quint8(QBluetoothDeviceInfo::UncategorizedWearableDevice)
+        << QBluetoothDeviceInfo::LowEnergyCoreConfiguration
+        << leDeviceUuid;
     QTest::newRow("0x000714 COD") << QBluetoothAddress("000000000000") << "My Bluetooth Device"
         << quint32(0x000714)
         << QBluetoothDeviceInfo::ServiceClasses(QBluetoothDeviceInfo::NoService)
         << QBluetoothDeviceInfo::WearableDevice
-        << quint8(QBluetoothDeviceInfo::WearableGlasses);
+        << quint8(QBluetoothDeviceInfo::WearableGlasses)
+        << QBluetoothDeviceInfo::LowEnergyCoreConfiguration
+        << leDeviceUuid;
     QTest::newRow("0x000800 COD") << QBluetoothAddress("000000000000") << "My Bluetooth Device"
         << quint32(0x000800)
         << QBluetoothDeviceInfo::ServiceClasses(QBluetoothDeviceInfo::NoService)
         << QBluetoothDeviceInfo::ToyDevice
-        << quint8(QBluetoothDeviceInfo::UncategorizedToy);
+        << quint8(QBluetoothDeviceInfo::UncategorizedToy)
+        << QBluetoothDeviceInfo::LowEnergyCoreConfiguration
+        << leDeviceUuid;
     QTest::newRow("0x000814 COD") << QBluetoothAddress("000000000000") << "My Bluetooth Device"
         << quint32(0x000814)
         << QBluetoothDeviceInfo::ServiceClasses(QBluetoothDeviceInfo::NoService)
         << QBluetoothDeviceInfo::ToyDevice
-        << quint8(QBluetoothDeviceInfo::ToyGame);
+        << quint8(QBluetoothDeviceInfo::ToyGame)
+        << QBluetoothDeviceInfo::LowEnergyCoreConfiguration
+        << leDeviceUuid;
     QTest::newRow("0x001f00 COD") << QBluetoothAddress("000000000000") << "My Bluetooth Device"
         << quint32(0x001f00)
         << QBluetoothDeviceInfo::ServiceClasses(QBluetoothDeviceInfo::NoService)
         << QBluetoothDeviceInfo::UncategorizedDevice
-        << quint8(0);
+        << quint8(0)
+        << QBluetoothDeviceInfo::LowEnergyCoreConfiguration
+        << leDeviceUuid;
     QTest::newRow("0x002000 COD") << QBluetoothAddress("000000000000") << "My Bluetooth Device"
         << quint32(0x002000)
         << QBluetoothDeviceInfo::ServiceClasses(QBluetoothDeviceInfo::PositioningService)
         << QBluetoothDeviceInfo::MiscellaneousDevice
-        << quint8(QBluetoothDeviceInfo::UncategorizedMiscellaneous);
+        << quint8(QBluetoothDeviceInfo::UncategorizedMiscellaneous)
+        << QBluetoothDeviceInfo::LowEnergyCoreConfiguration
+        << leDeviceUuid;
     QTest::newRow("0x100000 COD") << QBluetoothAddress("000000000000") << "My Bluetooth Device"
         << quint32(0x100000)
         << QBluetoothDeviceInfo::ServiceClasses(QBluetoothDeviceInfo::InformationService)
         << QBluetoothDeviceInfo::MiscellaneousDevice
-        << quint8(QBluetoothDeviceInfo::UncategorizedMiscellaneous);
+        << quint8(QBluetoothDeviceInfo::UncategorizedMiscellaneous)
+        << QBluetoothDeviceInfo::LowEnergyCoreConfiguration
+        << leDeviceUuid;
     QTest::newRow("0xFFE000 COD") << QBluetoothAddress("000000000000") << "My Bluetooth Device"
         << quint32(0xFFE000)
         << QBluetoothDeviceInfo::ServiceClasses(QBluetoothDeviceInfo::AllServices)
         << QBluetoothDeviceInfo::MiscellaneousDevice
-        << quint8(QBluetoothDeviceInfo::UncategorizedMiscellaneous);
+        << quint8(QBluetoothDeviceInfo::UncategorizedMiscellaneous)
+        << QBluetoothDeviceInfo::LowEnergyCoreConfiguration
+        << leDeviceUuid;
 }
 
 void tst_QBluetoothDeviceInfo::tst_construction()
@@ -232,6 +281,8 @@ void tst_QBluetoothDeviceInfo::tst_construction()
         QBluetoothDeviceInfo deviceInfo;
 
         QVERIFY(!deviceInfo.isValid());
+        QVERIFY(deviceInfo.coreConfigurations()
+                    == QBluetoothDeviceInfo::UnknownCoreConfiguration);
     }
 
     {
@@ -241,9 +292,10 @@ void tst_QBluetoothDeviceInfo::tst_construction()
         QFETCH(QBluetoothDeviceInfo::ServiceClasses, serviceClasses);
         QFETCH(QBluetoothDeviceInfo::MajorDeviceClass, majorDeviceClass);
         QFETCH(quint8, minorDeviceClass);
+        QFETCH(QBluetoothDeviceInfo::CoreConfiguration, coreConfiguration);
+        QFETCH(QBluetoothUuid, deviceUuid);
 
         QBluetoothDeviceInfo deviceInfo(address, name, classOfDevice);
-
         QVERIFY(deviceInfo.isValid());
 
         QCOMPARE(deviceInfo.address(), address);
@@ -251,9 +303,15 @@ void tst_QBluetoothDeviceInfo::tst_construction()
         QCOMPARE(deviceInfo.serviceClasses(), serviceClasses);
         QCOMPARE(deviceInfo.majorDeviceClass(), majorDeviceClass);
         QCOMPARE(deviceInfo.minorDeviceClass(), minorDeviceClass);
+        QCOMPARE(deviceInfo.coreConfigurations(), QBluetoothDeviceInfo::UnknownCoreConfiguration);
+
+        deviceInfo.setCoreConfigurations(coreConfiguration);
+        QCOMPARE(deviceInfo.coreConfigurations(), coreConfiguration);
+
+        deviceInfo.setDeviceUuid(deviceUuid);
+        QCOMPARE(deviceInfo.deviceUuid(), deviceUuid);
 
         QBluetoothDeviceInfo copyInfo(deviceInfo);
-
         QVERIFY(copyInfo.isValid());
 
         QCOMPARE(copyInfo.address(), address);
@@ -261,6 +319,41 @@ void tst_QBluetoothDeviceInfo::tst_construction()
         QCOMPARE(copyInfo.serviceClasses(), serviceClasses);
         QCOMPARE(copyInfo.majorDeviceClass(), majorDeviceClass);
         QCOMPARE(copyInfo.minorDeviceClass(), minorDeviceClass);
+        QCOMPARE(copyInfo.coreConfigurations(), coreConfiguration);
+        QCOMPARE(copyInfo.deviceUuid(), deviceUuid);
+    }
+
+    {
+        // Test construction from the device unique UUID, without an address.
+        QFETCH(QString, name);
+        QFETCH(quint32, classOfDevice);
+        QFETCH(QBluetoothDeviceInfo::ServiceClasses, serviceClasses);
+        QFETCH(QBluetoothDeviceInfo::MajorDeviceClass, majorDeviceClass);
+        QFETCH(quint8, minorDeviceClass);
+        QFETCH(QBluetoothDeviceInfo::CoreConfiguration, coreConfiguration);
+        QFETCH(QBluetoothUuid, deviceUuid);
+
+        QBluetoothDeviceInfo deviceInfo(deviceUuid, name, classOfDevice);
+        QVERIFY(deviceInfo.isValid());
+
+        QCOMPARE(deviceInfo.name(), name);
+        QCOMPARE(deviceInfo.serviceClasses(), serviceClasses);
+        QCOMPARE(deviceInfo.majorDeviceClass(), majorDeviceClass);
+        QCOMPARE(deviceInfo.minorDeviceClass(), minorDeviceClass);
+        QCOMPARE(deviceInfo.coreConfigurations(), QBluetoothDeviceInfo::UnknownCoreConfiguration);
+
+        deviceInfo.setCoreConfigurations(coreConfiguration);
+        QCOMPARE(deviceInfo.coreConfigurations(), coreConfiguration);
+
+        QBluetoothDeviceInfo copyInfo(deviceInfo);
+        QVERIFY(copyInfo.isValid());
+
+        QCOMPARE(copyInfo.name(), name);
+        QCOMPARE(copyInfo.serviceClasses(), serviceClasses);
+        QCOMPARE(copyInfo.majorDeviceClass(), majorDeviceClass);
+        QCOMPARE(copyInfo.minorDeviceClass(), minorDeviceClass);
+        QCOMPARE(copyInfo.coreConfigurations(), coreConfiguration);
+        QCOMPARE(copyInfo.deviceUuid(), deviceUuid);
     }
 }
 
@@ -277,9 +370,14 @@ void tst_QBluetoothDeviceInfo::tst_assignment()
     QFETCH(QBluetoothDeviceInfo::ServiceClasses, serviceClasses);
     QFETCH(QBluetoothDeviceInfo::MajorDeviceClass, majorDeviceClass);
     QFETCH(quint8, minorDeviceClass);
+    QFETCH(QBluetoothDeviceInfo::CoreConfiguration, coreConfiguration);
+    QFETCH(QBluetoothUuid, deviceUuid);
 
     QBluetoothDeviceInfo deviceInfo(address, name, classOfDevice);
 
+    deviceInfo.setDeviceUuid(deviceUuid);
+    deviceInfo.setCoreConfigurations(coreConfiguration);
+
     QVERIFY(deviceInfo.isValid());
 
     {
@@ -292,6 +390,8 @@ void tst_QBluetoothDeviceInfo::tst_assignment()
         QCOMPARE(copyInfo.serviceClasses(), serviceClasses);
         QCOMPARE(copyInfo.majorDeviceClass(), majorDeviceClass);
         QCOMPARE(copyInfo.minorDeviceClass(), minorDeviceClass);
+        QCOMPARE(copyInfo.coreConfigurations(), coreConfiguration);
+        QCOMPARE(copyInfo.deviceUuid(), deviceUuid);
     }
 
     {
@@ -308,6 +408,8 @@ void tst_QBluetoothDeviceInfo::tst_assignment()
         QCOMPARE(copyInfo.serviceClasses(), serviceClasses);
         QCOMPARE(copyInfo.majorDeviceClass(), majorDeviceClass);
         QCOMPARE(copyInfo.minorDeviceClass(), minorDeviceClass);
+        QCOMPARE(copyInfo.coreConfigurations(), coreConfiguration);
+        QCOMPARE(copyInfo.deviceUuid(), deviceUuid);
     }
 
     {
@@ -333,6 +435,10 @@ void tst_QBluetoothDeviceInfo::tst_assignment()
         QCOMPARE(copyInfo2.majorDeviceClass(), majorDeviceClass);
         QCOMPARE(copyInfo1.minorDeviceClass(), minorDeviceClass);
         QCOMPARE(copyInfo2.minorDeviceClass(), minorDeviceClass);
+        QCOMPARE(copyInfo1.coreConfigurations(), coreConfiguration);
+        QCOMPARE(copyInfo2.coreConfigurations(), coreConfiguration);
+        QCOMPARE(copyInfo1.deviceUuid(), deviceUuid);
+        QCOMPARE(copyInfo2.deviceUuid(), deviceUuid);
     }
 
     {
@@ -373,6 +479,47 @@ void tst_QBluetoothDeviceInfo::tst_cached()
     QVERIFY(!(deviceInfo.isCached()));
 }
 
+void tst_QBluetoothDeviceInfo::tst_flags()
+{
+    QBluetoothDeviceInfo::CoreConfigurations flags1(QBluetoothDeviceInfo::LowEnergyCoreConfiguration);
+    QBluetoothDeviceInfo::CoreConfigurations flags2(QBluetoothDeviceInfo::BaseRateCoreConfiguration);
+    QBluetoothDeviceInfo::CoreConfigurations result;
+
+    // test QFlags &operator|=(QFlags f)
+    result = flags1 | flags2;
+    QVERIFY(result.testFlag(QBluetoothDeviceInfo::LowEnergyCoreConfiguration));
+    QVERIFY(result.testFlag(QBluetoothDeviceInfo::BaseRateCoreConfiguration));
+
+    // test QFlags &operator|=(Enum f)
+    result = flags1 | QBluetoothDeviceInfo::BaseRateCoreConfiguration;
+    QVERIFY(result.testFlag(QBluetoothDeviceInfo::LowEnergyCoreConfiguration));
+    QVERIFY(result.testFlag(QBluetoothDeviceInfo::BaseRateCoreConfiguration));
+
+    // test Q_DECLARE_OPERATORS_FOR_FLAGS(QBluetoothDeviceInfo::CoreConfigurations)
+    result = QBluetoothDeviceInfo::BaseRateCoreConfiguration | flags1;
+    QVERIFY(result.testFlag(QBluetoothDeviceInfo::LowEnergyCoreConfiguration));
+    QVERIFY(result.testFlag(QBluetoothDeviceInfo::BaseRateCoreConfiguration));
+
+    QBluetoothDeviceInfo::ServiceClasses serviceFlag1(QBluetoothDeviceInfo::AudioService);
+    QBluetoothDeviceInfo::ServiceClasses serviceFlag2(QBluetoothDeviceInfo::CapturingService);
+    QBluetoothDeviceInfo::ServiceClasses serviceResult;
+
+    // test QFlags &operator|=(QFlags f)
+    serviceResult = serviceFlag1 | serviceFlag2;
+    QVERIFY(serviceResult.testFlag(QBluetoothDeviceInfo::AudioService));
+    QVERIFY(serviceResult.testFlag(QBluetoothDeviceInfo::CapturingService));
+
+    // test QFlags &operator|=(Enum f)
+    serviceResult = serviceFlag1 | QBluetoothDeviceInfo::CapturingService;
+    QVERIFY(serviceResult.testFlag(QBluetoothDeviceInfo::AudioService));
+    QVERIFY(serviceResult.testFlag(QBluetoothDeviceInfo::CapturingService));
+
+    // test Q_DECLARE_OPERATORS_FOR_FLAGS(QBluetoothDeviceInfo::ServiceClasses)
+    serviceResult = QBluetoothDeviceInfo::CapturingService | serviceFlag1;
+    QVERIFY(serviceResult.testFlag(QBluetoothDeviceInfo::AudioService));
+    QVERIFY(serviceResult.testFlag(QBluetoothDeviceInfo::CapturingService));
+}
+
 QTEST_MAIN(tst_QBluetoothDeviceInfo)
 
 #include "tst_qbluetoothdeviceinfo.moc"
