@@ -1,7 +1,7 @@
 /****************************************************************************
 **
-** Copyright (C) 2014 Digia Plc and/or its subsidiary(-ies).
-** Contact: http://www.qt-project.org/legal
+** Copyright (C) 2015 The Qt Company Ltd.
+** Contact: http://www.qt.io/licensing/
 **
 ** This file is part of the QtBluetooth module of the Qt Toolkit.
 **
@@ -10,9 +10,9 @@
 ** Licensees holding valid commercial Qt licenses may use this file in
 ** accordance with the commercial license agreement provided with the
 ** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and Digia. For licensing terms and
-** conditions see http://qt.digia.com/licensing. For further information
-** use the contact form at http://qt.digia.com/contact-us.
+** a written agreement between you and The Qt Company. For licensing terms
+** and conditions see http://www.qt.io/terms-conditions. For further
+** information use the contact form at http://www.qt.io/contact-us.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
@@ -23,8 +23,8 @@
 ** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
 ** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
-** In addition, as a special exception, Digia gives you certain additional
-** rights. These rights are described in the Digia Qt LGPL Exception
+** As a special exception, The Qt Company gives you certain additional
+** rights. These rights are described in The Qt Company LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
 ** $QT_END_LICENSE$
@@ -34,6 +34,7 @@
 #include <QtTest/QtTest>
 
 #include <QDebug>
+#include <QLoggingCategory>
 #include <QVariant>
 #include <QList>
 
@@ -46,9 +47,6 @@
 
 QT_USE_NAMESPACE
 
-Q_DECLARE_METATYPE(QBluetoothDeviceInfo)
-Q_DECLARE_METATYPE(QBluetoothServiceDiscoveryAgent::Error)
-
 // Maximum time to for bluetooth device scan
 const int MaxScanTime = 5 * 60 * 1000;  // 5 minutes in ms
 
@@ -80,7 +78,10 @@ private:
 
 tst_QBluetoothServiceDiscoveryAgent::tst_QBluetoothServiceDiscoveryAgent()
 {
+    QLoggingCategory::setFilterRules(QStringLiteral("qt.bluetooth* = true"));
+
     // start Bluetooth if not started
+#ifndef Q_OS_OSX
     QBluetoothLocalDevice *device = new QBluetoothLocalDevice();
     localDeviceAvailable = device->isValid();
     if (localDeviceAvailable) {
@@ -89,12 +90,16 @@ tst_QBluetoothServiceDiscoveryAgent::tst_QBluetoothServiceDiscoveryAgent()
         QTest::qWait(1000);
     }
     delete device;
+#else
+    QBluetoothLocalDevice device;
+    localDeviceAvailable = QBluetoothLocalDevice().hostMode() != QBluetoothLocalDevice::HostPoweredOff;
+#endif
 
-    qRegisterMetaType<QBluetoothDeviceInfo>("QBluetoothDeviceInfo");
-    qRegisterMetaType<QBluetoothServiceInfo>("QBluetoothServiceInfo");
-    qRegisterMetaType<QList<QBluetoothUuid> >("QList<QBluetoothUuid>");
-    qRegisterMetaType<QBluetoothServiceDiscoveryAgent::Error>("QBluetoothServiceDiscoveryAgent::Error");
-    qRegisterMetaType<QBluetoothDeviceDiscoveryAgent::Error>("QBluetoothDeviceDiscoveryAgent::Error");
+    qRegisterMetaType<QBluetoothDeviceInfo>();
+    qRegisterMetaType<QBluetoothServiceInfo>();
+    qRegisterMetaType<QList<QBluetoothUuid> >();
+    qRegisterMetaType<QBluetoothServiceDiscoveryAgent::Error>();
+    qRegisterMetaType<QBluetoothDeviceDiscoveryAgent::Error>();
 
 }
 
@@ -144,6 +149,10 @@ void tst_QBluetoothServiceDiscoveryAgent::initTestCase()
 
 void tst_QBluetoothServiceDiscoveryAgent::tst_invalidBtAddress()
 {
+#ifdef Q_OS_OSX
+    if (!localDeviceAvailable)
+        QSKIP("On OS X this test requires Bluetooth adapter in powered ON state");
+#endif
     QBluetoothServiceDiscoveryAgent *discoveryAgent = new QBluetoothServiceDiscoveryAgent(QBluetoothAddress("11:11:11:11:11:11"));
 
     QCOMPARE(discoveryAgent->error(), QBluetoothServiceDiscoveryAgent::InvalidBluetoothAdapterError);
@@ -380,7 +389,7 @@ void tst_QBluetoothServiceDiscoveryAgent::tst_serviceDiscovery()
     connect(&discoveryAgent, SIGNAL(error(QBluetoothServiceDiscoveryAgent::Error)),
             this, SLOT(serviceError(QBluetoothServiceDiscoveryAgent::Error)));
 
-    discoveryAgent.start();
+    discoveryAgent.start(QBluetoothServiceDiscoveryAgent::FullDiscovery);
 
     /*
      * Either we wait for discovery agent to run its course (e.g. Bluez 4) or
@@ -414,6 +423,7 @@ void tst_QBluetoothServiceDiscoveryAgent::tst_serviceDiscovery()
     }
 
     // All returned QBluetoothServiceInfo should be valid.
+    bool servicesFound = !discoveredSpy.isEmpty();
     while (!discoveredSpy.isEmpty()) {
         const QVariant v = discoveredSpy.takeFirst().at(0);
         // Work around limitation in QMetaType and moc.
@@ -442,7 +452,8 @@ void tst_QBluetoothServiceDiscoveryAgent::tst_serviceDiscovery()
 
     }
 
-    QVERIFY(discoveryAgent.discoveredServices().count() != 0);
+    if (servicesFound)
+        QVERIFY(discoveryAgent.discoveredServices().count() != 0);
     discoveryAgent.clear();
     QVERIFY(discoveryAgent.discoveredServices().count() == 0);
 
